# Version 0.0
*8/10/2017*

* Forked this project from **PyAIML version 0.8.6**.
* Renamed from **PyAIML** to **aiml_bot**. There are several packages derived
  from Cort's original project available on the Python Package Index. This
  rename is intended to avoid import name clashes while simultaneously
  allowing the project and import names to agree.
* Reset versioning to 0.0 to account for the major refactoring and the
  project fork and renaming.
